@@ -2,8 +2,10 @@ from .indices import NoopIndex, ColumnsIndex, MultiIndex
 from .similarities import StringSimilarity, DateSimilarity, JaroWinklerSimilarity
 from .matchers import ThresholdMatcher
 from .variators import Variator, Swap
+from .filters import DissimilarFilter, NonOverlappingFilter
 
 __all__ = [
     "NoopIndex", "ColumnsIndex", "JaroWinklerSimilarity", "StringSimilarity",
-    "DateSimilarity", "ThresholdMatcher", "MultiIndex", "Variator", "Swap"
+    "DateSimilarity", "ThresholdMatcher", "MultiIndex", "Variator", "Swap",
+    "DissimilarFilter", "NonOverlappingFilter"
 ]
